Uses of Interface org.openqa.selenium.server.htmlrunner.HTMLResultsListener (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Uses of Interface
org.openqa.selenium.server.htmlrunner.HTMLResultsListener

Packages that use HTMLResultsListener
org.openqa.selenium.server | Provides the core Selenium Server classes.
org.openqa.selenium.server.htmlrunner | Provides classes to launch Selenium Core HTML test suites and handle their test results.

Uses of HTMLResultsListener in org.openqa.selenium.server

Methods in org.openqa.selenium.server with parameters of type HTMLResultsListener
`void` | `SeleniumServer.handleHTMLRunnerResults(HTMLResultsListener listener)`

Uses of HTMLResultsListener in org.openqa.selenium.server.htmlrunner

Classes in org.openqa.selenium.server.htmlrunner that implement HTMLResultsListener
`class` | `HTMLLauncher` Runs HTML Selenium test suites.

Methods in org.openqa.selenium.server.htmlrunner with parameters of type HTMLResultsListener
`void` | `SeleniumHTMLRunnerResultsHandler.addListener(HTMLResultsListener listener)`

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.